==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPivotGridColumnDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPivotGridColumnDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPivotGridColumnDescription, _super);
    function WebPivotGridColumnDescription() {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.f = null;
        _this.h = null;
        return _this;
    }
    WebPivotGridColumnDescription.prototype.get_type = function () {
        return "WebPivotGridColumn";
    };
    Object.defineProperty(WebPivotGridColumnDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPivotGridColumnDescription.prototype, "field", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.e("Field");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPivotGridColumnDescription.prototype, "dimensions", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Dimensions");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPivotGridColumnDescription.prototype, "value", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("Value");
        },
        enumerable: true,
        configurable: true
    });
    WebPivotGridColumnDescription.$t = markType(WebPivotGridColumnDescription, 'WebPivotGridColumnDescription', Description.$);
    return WebPivotGridColumnDescription;
}(Description));
export { WebPivotGridColumnDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebPivotGridColumnDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPivotGridColumnDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotGridColumnDescription, _super);
    function WebPivotGridColumnDescription() {
        var _this = _super.call(this) || this;
        _this.l = null;
        _this.h = null;
        _this.j = null;
        return _this;
    }
    WebPivotGridColumnDescription.prototype.get_type = function () {
        return "WebPivotGridColumn";
    };
    Object.defineProperty(WebPivotGridColumnDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridColumnDescription.prototype, "field", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.g("Field");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridColumnDescription.prototype, "dimensions", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Dimensions");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridColumnDescription.prototype, "value", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("Value");
        },
        enumerable: false,
        configurable: true
    });
    WebPivotGridColumnDescription.$t = markType(WebPivotGridColumnDescription, 'WebPivotGridColumnDescription', Description.$);
    return WebPivotGridColumnDescription;
}(Description));
export { WebPivotGridColumnDescription };
